@@ -14,7 +14,6 @@
 #  limitations under the License.
 # ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 import numpy as np
-from datetime import datetime
 
 from quocslib.stoppingcriteria.StoppingCriteria import StoppingCriteria
 
@@ -29,31 +28,30 @@ class NelderMeadStoppingCriteria(StoppingCriteria):
         :param dict stopping_criteria: dictionary of specific stopping criteria
         """
         # Call to the super class constructor
-        super().__init__()
-        # Maximum function evaluation number
-        self.max_eval = stopping_criteria.setdefault("max_eval", 100)
+        super().__init__(stopping_criteria)
         # frtol and xatol
         self.xatol = stopping_criteria.setdefault("xatol", 1e-14)
         self.frtol = stopping_criteria.setdefault("frtol", 1e-13)
-        self.FoM_goal = stopping_criteria.setdefault("FoM_goal", -10**10)
-        self.time_lim = stopping_criteria.setdefault("time_lim", 10**10)
-        self.start_time = datetime.now()
         self.is_converged = False
 
     def check_stopping_criteria(self,
                                 sim: np.array = None,
                                 fsim: np.array = None,
-                                function_evaluations: int = None) -> None:
+                                func_evaluations_single_direct_search: int = None) -> None:
         """
 
         :param sim:
         :param fsim:
-        :param function_evaluations:
+        :param func_evaluations_single_direct_search:
         :return:
         """
         if self.is_converged: return
 
-        self.is_converged, self.terminate_reason = self.check_func_eval(function_evaluations)
+        self.is_converged, self.terminate_reason = self.check_func_eval_total(func_evaluations_single_direct_search)
+        if self.is_converged: return
+
+        self.is_converged, self.terminate_reason = self.check_func_eval_single_direct_search(
+            func_evaluations_single_direct_search)
         if self.is_converged: return
 
         self.is_converged, self.terminate_reason = self.check_simplex_criterion(sim)
@@ -65,5 +63,8 @@ class NelderMeadStoppingCriteria(StoppingCriteria):
         self.is_converged, self.terminate_reason = self.check_goal_reached(fsim[0])
         if self.is_converged: return
 
-        self.is_converged, self.terminate_reason = self.check_time_out()
+        self.is_converged, self.terminate_reason = self.check_total_time_out()
+        if self.is_converged: return
+
+        self.is_converged, self.terminate_reason = self.check_direct_search_time_out()
         if self.is_converged: return
